@@ -53,7 +53,7 @@ var subTypeNames = scalar.StrMapDescription{
 	"subp": "Subpicture",
 	"text": "Text",
 	"tmcd": "Time Code",
-	"url ": "URL",
+	"url":  "URL",
 	"vide": "Video Track",
 }
 
@@ -101,7 +101,7 @@ var dataFormatNames = scalar.StrMapDescription{
 	"encs": "Encrypted Systems stream",
 	"enct": "Encrypted Text",
 	"encv": "Encrypted/protected video",
-	"fdp ": "File delivery hints",
+	"fdp":  "File delivery hints",
 	"fLaC": "Fres Lossless Audio Codec",
 	"g719": "ITU-T Recommendation G.719 (2008)",
 	"g726": "ITU-T Recommendation G.726 (1990)",
@@ -138,13 +138,13 @@ var dataFormatNames = scalar.StrMapDescription{
 	"Opus": "Opus audio coding",
 	"pm2t": "Protected MPEG-2 Transport",
 	"prtp": "Protected RTP Reception",
-	"raw ": "Uncompressed audio",
+	"raw":  "Uncompressed audio",
 	"resv": "Restricted Video",
 	"rm2t": "MPEG-2 Transport Reception",
 	"rrtp": "RTP reception",
 	"rsrp": "SRTP Reception",
 	"rtmd": "Real Time Metadata Sample Entry(XAVC Format)",
-	"rtp ": "RTP Hints",
+	"rtp":  "RTP Hints",
 	"s263": "ITU H.263 video (3GPP format)",
 	"samr": "Narrowband AMR voice",
 	"sawb": "Wideband AMR voice",
@@ -248,7 +248,7 @@ func decodeSampleFlags(d *decode.D) {
 
 func decodeBoxWithParentData(ctx *decodeContext, d *decode.D, parentData any, extraTypeMappers ...scalar.StrMapper) {
 	var dataSize uint64
-	typeMappers := []scalar.StrMapper{boxDescriptions}
+	typeMappers := []scalar.StrMapper{scalar.ActualTrimSpace, boxDescriptions}
 	if len(extraTypeMappers) > 0 {
 		typeMappers = append(typeMappers, extraTypeMappers...)
 	}
@@ -339,13 +339,7 @@ type keysBox struct {
 	keys []keysBoxKey
 }
 
-func decodeBoxIrefEntry(ctx *decodeContext, d *decode.D) {
-	irefBox, ok := ctx.parent().data.(*irefBox)
-	if !ok {
-		d.FieldRawLen("data", d.BitsLeft())
-		return
-	}
-
+func decodeBoxIrefEntry(irefBox *irefBox, d *decode.D) {
 	idSize := 16
 	if irefBox.version != 0 {
 		idSize = 32
@@ -525,7 +519,7 @@ func decodeBox(ctx *decodeContext, d *decode.D, typ string) {
 		d.FieldU8("version")
 		d.FieldU24("flags")
 		d.FieldUTF8NullFixedLen("component_type", 4)
-		subType := d.FieldUTF8("component_subtype", 4, subTypeNames, scalar.ActualTrimSpace)
+		subType := d.FieldUTF8("component_subtype", 4, scalar.ActualTrimSpace, subTypeNames)
 		d.FieldUTF8NullFixedLen("component_manufacturer", 4)
 		d.FieldU32("component_flags")
 		d.FieldU32("component_flags_mask")
@@ -533,7 +527,12 @@ func decodeBox(ctx *decodeContext, d *decode.D, typ string) {
 		switch majorBrand {
 		case "qt":
 			// qt brand seems to use length prefixed strings
-			d.FieldUTF8ShortStringFixedLen("component_name", int(d.BitsLeft()/8))
+			// From QuickTime File Format specification:
+			// > A (counted) string that specifies the name of the component—that is, the media handler used
+			// > when this media was created. This field may contain a zero-length (empty) string.
+			if d.BitsLeft() > 0 {
+				d.FieldUTF8ShortStringFixedLen("component_name", int(d.BitsLeft()/8))
+			}
 		default:
 			d.FieldUTF8NullFixedLen("component_name", int(d.BitsLeft()/8))
 		}
@@ -560,12 +559,12 @@ func decodeBox(ctx *decodeContext, d *decode.D, typ string) {
 		var drefURL string
 		d.FieldStructArrayLoop("boxes", "box", func() bool { return i < entryCount }, func(d *decode.D) {
 			size := d.FieldU32("size")
-			typ := d.FieldUTF8("type", 4)
+			typ := d.FieldUTF8("type", 4, scalar.ActualTrimSpace)
 			d.FieldU8("version")
 			d.FieldU24("flags")
 			dataSize := size - 12
 			switch typ {
-			case "url ":
+			case "url":
 				drefURL = d.FieldUTF8("data", int(dataSize))
 			default:
 				d.FieldRawLen("data", int64(dataSize*8))
@@ -590,7 +589,7 @@ func decodeBox(ctx *decodeContext, d *decode.D, typ string) {
 		d.FieldArrayLoop("boxes", func() bool { return i < entryCount }, func(d *decode.D) {
 			d.FieldStruct("box", func(d *decode.D) {
 				size := d.FieldU32("size")
-				dataFormat := d.FieldUTF8("type", 4, dataFormatNames)
+				dataFormat := d.FieldUTF8("type", 4, dataFormatNames, scalar.ActualTrimSpace)
 				subType := ""
 				if t := ctx.currentTrack(); t != nil {
 					t.sampleDescriptions = append(t.sampleDescriptions, sampleDescription{
@@ -1243,7 +1242,7 @@ func decodeBox(ctx *decodeContext, d *decode.D, typ string) {
 				if !d.End() {
 					d.FieldUTF8Null("content_encoding")
 				}
-			case "uri ":
+			case "uri":
 				d.FieldUTF8Null("item_uri_type")
 			}
 		}
@@ -1709,11 +1708,26 @@ func decodeBox(ctx *decodeContext, d *decode.D, typ string) {
 		d.FieldU24("flags")
 		decodeBoxesWithParentData(ctx, d, &irefBox{version: int(version)})
 	case "dimg":
-		decodeBoxIrefEntry(ctx, d)
+		if irefBox, ok := ctx.parent().data.(*irefBox); ok {
+			decodeBoxIrefEntry(irefBox, d)
+		} else {
+			d.FieldRawLen("data", d.BitsLeft())
+		}
 	case "thmb":
-		decodeBoxIrefEntry(ctx, d)
+		if irefBox, ok := ctx.parent().data.(*irefBox); ok {
+			decodeBoxIrefEntry(irefBox, d)
+		} else {
+			d.FieldU8("version")
+			d.FieldU24("flags")
+			d.FieldUTF8("format", 4)
+			d.FieldFormatOrRawLen("image", d.BitsLeft(), &imageGroup, nil)
+		}
 	case "cdsc":
-		decodeBoxIrefEntry(ctx, d)
+		if irefBox, ok := ctx.parent().data.(*irefBox); ok {
+			decodeBoxIrefEntry(irefBox, d)
+		} else {
+			d.FieldRawLen("data", d.BitsLeft())
+		}
 	case "irot":
 		d.FieldU8("rotation", scalar.UintMapSymUint{
 			0: 0,
@@ -1784,6 +1798,40 @@ func decodeBox(ctx *decodeContext, d *decode.D, typ string) {
 		default:
 			d.FieldRawLen("message_data", d.BitsLeft())
 		}
+	case "jp2h":
+		decodeBoxes(ctx, d)
+	case "ihdr":
+		d.FieldU32("width")
+		d.FieldU32("height")
+		d.FieldU16("nc")
+		d.FieldU8("bpc", scalar.UintActualAdd(1))
+		d.FieldU8("c", scalar.UintMapSymStr{
+			0: "uncompressed",
+			1: "modified_huffman",
+			2: "modified_read",
+			3: "modified_modified_read",
+			4: "jbig_bi_level",
+			5: "jpeg",
+			6: "jpeg_ls",
+			7: "jpeg_2000",
+			8: "jbig2",
+			9: "jbig",
+		})
+		d.FieldU8("unk_c")
+		d.FieldU8("ipr")
+	case "jP":
+		d.FieldRawLen("signature", 4*8, d.AssertBitBuf([]byte{0x0d, 0x0a, 0x87, 0x0a}))
+	case "jp2c":
+		d.FieldFormat("segments", &jp2cGroup, nil)
+	case "uinf":
+		decodeBoxes(ctx, d)
+	case "ulst":
+		nu := d.FieldU16("nu")
+		d.FieldArray("uids", func(d *decode.D) {
+			for i := 0; i < int(nu); i++ {
+				d.FieldRawLen("uid", 128)
+			}
+		})
 
 	default:
 		// there are at least 4 ways to encode udta metadata in mov/mp4 files.
